@@ -1,12 +1,9 @@
 """
 Copyright 2021-present Airbnb, Inc.
-
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
-
    http://www.apache.org/licenses/LICENSE-2.0
-
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -38,15 +35,28 @@ class LetsEncrypt:
         self.subdelegate = subdelegate
         self.region = region
         self.hostname = self._validate_device_connection(hostname)
+        self.subdomain = self._get_subdomain(hostname)
         self.subject_alternative_names = self._validate_subdelegate_zone(
             subject_alternative_names)
-        self.subdomain = self._get_subdomain(hostname)
 
     def _get_subdomain(self, hostname: str) -> str:
         return tldextract.extract(
             self.hostname).subdomain
 
-    def _validate_device_connection(self, hostname, timeout=5):
+    def _query_acme_challenge_records(self, hostname: str, hosted_zone: str) -> bool:
+        client = boto3.client('route53')
+        paginator = client.get_paginator(
+            'list_resource_record_sets')
+        try:
+            for page in paginator.paginate(HostedZoneId=hosted_zone):
+                for record in page["ResourceRecordSets"]:
+                    if (f'_acme-challenge.{hostname}') in record['Name']:
+                        return True
+            return False
+        except Exception:
+            raise KeyError('HOSTED_ZONE_ID Invalid')
+
+    def _validate_device_connection(self, hostname: str, timeout=5):
         try:
             # Validate Device is Up
             scanner = nmap.PortScanner()
@@ -60,25 +70,12 @@ class LetsEncrypt:
 
     def _validate_subdelegate_zone(self, subject_alternative_names: List[str]) -> None:
         client = boto3.client('route53')
-
         for hostname in subject_alternative_names:
-            try:
-                hosted_zone = os.environ['HOSTED_ZONE_ID']
-                response = client.list_resource_record_sets(
-                    HostedZoneId=hosted_zone,
-                    StartRecordName='_acme-challenge.{hostname}'.format(
-                        hostname=hostname),
-                    StartRecordType='CNAME',
-                    MaxItems='1'
-                )['ResourceRecordSets'][0]['Name']
-
-                if response != '_acme-challenge.{hostname}.'.format(hostname=hostname):
-                    LOGGER.warning('Invalid Challenge Alias: {hostname}'.format(
-                        hostname=hostname))
-                    sys.exit(1)
-
-            except Exception:
-                raise KeyError('HOSTED_ZONE_ID Invalid')
+            hosted_zone = os.environ['HOSTED_ZONE_ID']
+            if not self._query_acme_challenge_records(hostname, hosted_zone):
+                LOGGER.warning('Invalid Challenge Alias: {hostname}'.format(
+                    hostname=hostname))
+                sys.exit(1)
 
     def _register_lets_encrypt_account(self) -> None:
         prefix = os.environ['PREFIX']
@@ -115,15 +112,15 @@ class LetsEncrypt:
 
     def acme_development(self, csr: str) -> None:  # pragma: no cover
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')))
+            '{directory}/acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
         subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_production(self, csr: str) -> None:  # pragma: no cover
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
+            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
         subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_local(self, csr: str) -> None:  # pragma: no cover
         subprocess.call(
@@ -131,26 +128,8 @@ class LetsEncrypt:
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
             directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
 
-    def acme_private_ca_local(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
-        prefix = os.environ['PREFIX']
-        root_certificate = get_secret(
-            f'{prefix}/otter/root_certificate', element=None, region=self.region)
-        with open('root_ca.crt', 'w') as outfile:
-            outfile.write(root_certificate)
-
+    def acme_local_production(self, csr: str) -> None:  # pragma: no cover
         subprocess.call(
-            '{directory}/.acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
-        subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
-
-    def acme_private_ca_production(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
-        prefix = os.environ['PREFIX']
-        root_certificate = get_secret(
-            f'{prefix}/otter/root_certificate', element=None, region=self.region)
-        with open('root_ca.crt', 'w') as outfile:
-            outfile.write(root_certificate)
-
-        subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
-        subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
+            '{directory}/.acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
+        subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
