@@ -1,7 +1,7 @@
 import json
 import requests
 
-from typing import Dict
+from typing import Dict, Optional, TextIO
 
 from .decorator import http_exception
 
@@ -13,24 +13,29 @@ class Request:
 
     @http_exception
     def get(self, url: str, headers: Dict = {}, query_params: Dict = {}):
+        print('here, get')
         if self.validation is False:
+            print('get, false')
             return self._requester_base.get(url, headers=headers, params=query_params, verify=False)
         else:
             return self._requester_base.get(url, headers=headers, params=query_params)
 
     @http_exception
-    def post(self, url: str, headers: Dict = {}, data: Dict = {}):
+    def post(self, url: str, files: Optional[Dict], headers: Dict = {}, data: Dict = {}):
+        print('here, post')
         if self.validation is False:
-            return self._requester_base.post(url, headers=headers, data=json.dumps(data), verify=False)
+            print('post, false')
+            return self._requester_base.post(url, files=files, headers=headers, data=data, verify=False)
         else:
-            return self._requester_base.post(url, headers=headers, data=json.dumps(data))
+            return self._requester_base.post(url, files=files, headers=headers, data=data)
 
     @http_exception
     def put(self, url: str, headers: Dict = {}, data: Dict = {}):
+        print('here, put')
         if self.validation is False:
-            return self._requester_base.put(url, headers=headers, data=json.dumps(data), verify=False)
+            return self._requester_base.put(url, headers=headers, data=data, verify=False)
         else:
-            return self._requester_base.put(url, headers=headers, data=json.dumps(data))
+            return self._requester_base.put(url, headers=headers, data=data)
 
     @http_exception
     def delete(self, url: str, headers: Dict = {}):
